function varargout = filters(type,dim,order,std)
%
% Returns convolution kernels
%
% [gx gy gxx gxy gyy w wd] = filters('OPT gauss','2D','1st 2nd')
%
%

k = 0;
h = 1;

% -------------------
% 1D

if strfind(dim,'1D')
    % Finite difference
    if strfind(type,'FD')
        gx = [-1 0 1]/(2*h);
        gy = gx';
        
        k = k+1; varargout(k) = {gx};
        k = k+1; varargout(k) = {gy};
    end
end

% -------------------
% 2D

if strfind(dim,'2D')
    
    % Finite difference
    if strfind(type,'FD')
        % 1st order
        if strfind(order,'1st')
            gx = [0 0 0;
                -1 0 1;
                0 0 0]/(2*h);
            gy = gx';
            k = k+1; varargout(k) = {gx};
            k = k+1; varargout(k) = {gy};
        end
        
        % 2nd order
        if strfind(order,'2nd')
            gxx = [0        0        0;
                1        -2       1;
                0        0        0]/(h^2);
            gyy = gxx';
            gxy = [1 0 -1; 0 0 0; -1 0 1]/4;
            k = k+1; varargout(k) = {gxx};
            k = k+1; varargout(k) = {gxy};
            k = k+1; varargout(k) = {gyy};
        end
    end
    
    
    % Optimized
    if strfind(type,'OPT')
        % 1st order
        if strfind(order,'1st')
            p = 1/4;
            gx = [-p        0       p;
                2*p-1     0       1-2*p;
                -p        0       p]*1/2;
            gy = gx';
            
            k = k+1; varargout(k) = {gx};
            k = k+1; varargout(k) = {gy};
        end
        
        % 2nd order
        if strfind(order,'2nd')
            q = 13/16;
            gxx = [q        -2*q        q; 4-2*q    -8+4*q      4-2*q; q        -2*q        q]*1/4;
            gyy = gxx';
            gxy = [1 0 -1; 0 0 0; -1 0 1]/4;
            
            k = k+1; varargout(k) = {gxx};
            k = k+1; varargout(k) = {gxy};
            k = k+1; varargout(k) = {gyy};
        end
    end
    
end



% -------------------
% Normalized Gaussian and its derivative
if strfind(type,'gauss')
    s = 1;
    x = -3:3;
      
    w = exp( - x.^2 ./ (2*s^2) );
    w = w./sum(w);
    
    wd = -x./(s^2) .* w;
    
    wdd = (x.^2 - s^2)./(s^4) .* w;
    
    k = k+1; varargout(k) = {w};
    k = k+1; varargout(k) = {wd};
    k = k+1; varargout(k) = {wdd};
end
