%
% Generate figures in paper 
%
% Following variables are of interest
%   name - name of test image
%   zoom - region of interest
%   sgm_pos - extract figure from noise level sgm_vec at sgm_pos
%
%  Uncommment the image of interest to be printed
%
% Figures are saved in folder "figures/name.eps"
%
% Freddie Astrom, Spring 2012, freddie.astrom@liu.se
%

close all
clear all
clc

run_method_vec = {'CACD' 'CEAD' 'AD-RGB' 'CBM3D'};

path2load = 'results/';
% path2load = '/local/';

name = '8143_owl'; ZOOM_X = 364:479; ZOOM_Y = 154:232; sgm_pos = 5;
% name = '175043_snake_green'; ZOOM_X = 185:358; ZOOM_Y = 137:293; sgm_pos = 4; 
% name = '208001_mushroom'; ZOOM_X = 211:290; ZOOM_Y = 220:299; sgm_pos = 3; 
% name = '87065_lizard'; ZOOM_X = 1:128; ZOOM_Y = 1:128; sgm_pos = 4; 

sgm_vec = [5 10 20 50 70];

datamat = []; 
for j = 1:numel(run_method_vec)
    loadname = [path2load 'finalmat_errors_estNoise_' run_method_vec{j} '_' name];
    load(loadname); data = finalmax;
    
    datamat = [datamat finalmax(:)];
end

% PRINT IMAGES FULL
filename = ['figures/' name '.eps'];

u0 = datamat{sgm_pos,1}{1}.u0;
u1 = datamat{sgm_pos,1}{1}.u1;

imagesc_print(u0,['figures/' name '_std' num2str(sgm_vec(sgm_pos)) '_u0.eps']);
imagesc_print(u1,['figures/' name '_std' num2str(sgm_vec(sgm_pos)) '_u1.eps']);

for i_alg = 1:size(run_method_vec,2)
    data = datamat{sgm_pos,i_alg}{1};
    data_name = data.scheme;
    imagesc_print(data.umax_ssim,['figures/' name '_std' num2str(sgm_vec(sgm_pos)) '_' data_name '.eps']);
    % data.umax_ssim
end

% PRINT IMAGES ZOOM
u0 = datamat{sgm_pos,1}{1}.u0(ZOOM_Y,ZOOM_X,:);
u1 = datamat{sgm_pos,1}{1}.u1(ZOOM_Y,ZOOM_X,:);

imagesc_print(u0,['figures/' name '_std' num2str(sgm_vec(sgm_pos)) '_zoom_u0.eps']);
imagesc_print(u1,['figures/' name '_std' num2str(sgm_vec(sgm_pos)) '_zoom_u1.eps']);

for i_alg = 1:size(run_method_vec,2)
    data = datamat{sgm_pos,i_alg}{1};
    data_name = data.scheme;
    imagesc_print(data.umax_ssim(ZOOM_Y,ZOOM_X,:),['figures/' name '_std' num2str(sgm_vec(sgm_pos)) '_zoom_' data_name '.eps']);
end

