% 
% Generate latex table for error values shown in the paper.
%
% Freddie Astrom, Spring 2012, freddie.astrom@liu.se
%

%
% Add latex function
% Download at http://www.mathworks.com/matlabcentral/fileexchange/2832
%
addpath(genpath('external/'))

close all
clear all
clc

path2load = 'results/';
% path2load = '/local/';

run_method_vec = {'CACD' 'CEAD' 'AD-RGB' 'CBM3D'}; 

%
% Load each of these name variables separately in order to generate 
% latex table with noise standard deviation, estimated noise, SSIM and PSNR 
%
name = '8143_owl';
% name = '175043_snake_green'; 
% name = '208001_mushroom'; 
% name = '87065_lizard';

% row: std, column: denoising method
%datamat = cell(6,4);
datamat = [];
for j = 1:numel(run_method_vec)
    % Path to saved data structures
    loadname = [path2load 'finalmat_errors_estNoise_' run_method_vec{j} '_' name];
    load(loadname); data = finalmax;
    datamat = [datamat finalmax(:)];
end

j = 0;
for i_std = 1:size(datamat,1)
    for i_alg = 1:size(datamat,2)
        data = datamat{i_std,i_alg}{1};
        ssim_vec(i_std,i_alg) = max(data.ssim);
        psnr_vec(i_std,i_alg) = max(data.psnr);
        noise_real(i_std,i_alg) = data.noise_real;
        noise_est(i_std,i_alg) = data.noise_est;
        label_vec(i_std,i_alg) = {data.scheme};
    end
end

matrix = [noise_real(:,1) noise_est(:,1) ssim_vec psnr_vec];

latex(matrix, '%i', '%.1f', '%.2f','%.2f','%.2f','%.2f','%.1f')

% Expected output: 

% Owl
% $5$  & $61.4$ & $0.99$ & $0.99$ & $0.98$ & $0.78$ & $36.9$ & $37.0$ & $34.6$ & $23.2$ \\
% $10$ & $19.8$ & $0.97$ & $0.97$ & $0.95$ & $0.96$ & $33.0$ & $33.0$ & $30.1$ & $32.0$ \\
% $20$ & $25.7$ & $0.93$ & $0.93$ & $0.88$ & $0.93$ & $27.8$ & $28.0$ & $25.8$ & $28.7$ \\
% $50$ & $65.1$ & $0.80$ & $0.81$ & $0.68$ & $0.72$ & $22.6$ & $23.0$ & $20.5$ & $21.8$ \\
% $70$ & $71.2$ & $0.71$ & $0.73$ & $0.59$ & $0.66$ & $20.4$ & $21.0$ & $18.8$ & $20.5$ 

% Snake Green
% $5$  & $15.5$ & $0.98$ & $0.98$ & $0.97$ & $0.96$ & $38.3$ & $38.3$ & $35.3$ & $34.6$ \\
% $10$ & $18.1$ & $0.95$ & $0.95$ & $0.92$ & $0.94$ & $33.0$ & $33.1$ & $30.9$ & $32.6$ \\
% $20$ & $23.5$ & $0.87$ & $0.88$ & $0.83$ & $0.90$ & $27.7$ & $28.4$ & $27.3$ & $29.7$ \\
% $50$ & $53.9$ & $0.69$ & $0.73$ & $0.63$ & $0.69$ & $23.2$ & $24.3$ & $23.0$ & $24.4$ \\
% $70$ & $65.4$ & $0.59$ & $0.64$ & $0.54$ & $0.61$ & $21.5$ & $22.7$ & $21.6$ & $22.9$   

% Mushroom
% $5$ & $9.9$ & $0.97$ & $0.97$ & $0.95$ & $0.96$ & $38.7$ & $38.9$ & $36.9$ & $38.2$ \\
% $10$ & $13.9$ & $0.92$ & $0.93$ & $0.89$ & $0.93$ & $33.8$ & $34.3$ & $32.8$ & $35.1$ \\
% $20$ & $21.1$ & $0.83$ & $0.86$ & $0.79$ & $0.88$ & $29.3$ & $30.4$ & $29.2$ & $31.8$ \\
% $50$ & $49.0$ & $0.66$ & $0.70$ & $0.58$ & $0.70$ & $25.1$ & $26.0$ & $24.7$ & $26.4$ \\
% $70$ & $60.4$ & $0.57$ & $0.62$ & $0.52$ & $0.63$ & $23.0$ & $23.8$ & $22.8$ & $24.1$   

% Lizard
% $5$ & $17.0$ & $0.99$ & $0.99$ & $0.98$ & $0.97$ & $38.0$ & $38.0$ & $35.2$ & $34.1$ \\
% $10$ & $19.2$ & $0.96$ & $0.96$ & $0.94$ & $0.95$ & $32.7$ & $32.8$ & $30.6$ & $32.3$ \\
% $20$ & $24.2$ & $0.90$ & $0.91$ & $0.87$ & $0.92$ & $27.3$ & $27.8$ & $26.7$ & $29.3$ \\
% $50$ & $57.1$ & $0.75$ & $0.77$ & $0.68$ & $0.73$ & $22.6$ & $23.5$ & $22.0$ & $23.2$ \\
% $70$ & $67.1$ & $0.65$ & $0.70$ & $0.59$ & $0.66$ & $20.8$ & $21.8$ & $20.5$ & $21.7$   




